D0???R1: Shedding the bikeshed: C++ papers should focus on content, not style

# D0???R1
Shedding the bikeshed: C++ papers should focus on content, not style

## Draft Proposal, 1970-01-01

This version:
  http://wg21.link/p0????
Author:
  JF Bastien
Audience:
  all
Toggle Diffs:
  Hide deleted text
Project:
  ISO/IEC JTC1/SC22/WG21 14882: Programming Language — C++
Source:
  github.com/jfbastien/papers/blob/master/source/bikeshed.bs

## Abstract

Writing a C++ standards committee paper can be as easy as riding a bicycle 🚲

## 1. Coloring the shed

Thoughtful standards people put significant effort into writing their papers. Often, too much of that effort goes into style or format instead of content. This meta-paper is ironically all style and no C++ content. It proposes that you stop formatting and start using bikeshed.

While we’re at it, we’ll also propose that you use a public version control service such as github to make it easier for reviewers to see how a paper evolved, both while in draft state as well as from one revision to another. Final papers are meant to be consumed as-is, but your paper collaborators, editors, or future-self will thank you when performing archaeology to untangle the inevitable nonsensical part of your final paper.

## 2. To do

https://github.com/tabatkins/bikeshed/blob/master/docs/quick-start.md

1. Basics

   - What does the final paper look like?

   - What does the source look like? (see section 4.)

   - Who uses it?

   - Takes care of the boilerplate

2. Convenience

   - Webpages work everywhere

   - Readable offline, no downloads

   - Unicode Just Works™ (even the EDG wiki now supports it)

3. Good practice

   - github for diffs: easier to track changes

   - github integration: auto-generation, etc

4. markdown + HTML escape hatch

   - https://github.com/tabatkins/bikeshed/blob/master/docs/markup.md

   - Railroad diagrams

   - Code, and syntax highlight

   - Toggle diff

5. Link to other papers

6. Getting started

   - Installing https://github.com/tabatkins/bikeshed/blob/master/docs/install.md